Provides the predicted values for the reserve demand curve of choice. For general use prefer the predict() function, which handles the constant internally.
curvepred(x, w, type = "logistic", dummy = NULL)Returns a vector of the predicted values.
A matrix with the inputs. If there is a constant in the estimated curve, then the first column in x should be the constant. Next column should be the excess reserves. Additional regressor follow (optional).
The vector of weights for the desired curve. Estimated using the curveopt function.
The type of the reserve demand curve. This can be any of logistic, redLogistic, fixLogistic, doubleExp, exponential, fixExponential, arctan, linear. See details in curve
Optional input to signify a regime change (vertical shifts in the curve). Must be a vector of equal length to the rows of x. If not needed use NULL.
Nikolaos Kourentzes, nikolaos@kourentzes.com
For a description of the parametric curves, see the provided reference. Below we list their functions:
logisitc (Logistic) $$r_i = \alpha + \kappa / (1 - \beta e^{g(\bm{C}_i)}) + \varepsilon_i$$
redLogistic (Reduced logistic) $$r_i = \alpha + 1 / (1 - \beta e^{g(\bm{C}_i)}) + \varepsilon_i$$
fixLogistic (Fixed logistic) $$r_i = \alpha + 1 / (1 - e^{g(\bm{C}_i)}) + \varepsilon_i$$
doubleExp (Double exponential) $$r_i = \alpha + \beta e^{\rho e^{g(\bm{C}_i)}} + \varepsilon_i$$
exponential (Exponential) $$r_i = \alpha + \beta e^{g(\bm{C}_i)} + \varepsilon_i$$
fixExponential (Fixed exponential) $$r_i = \beta e^{g(\bm{C}_i)} + \varepsilon_i$$
arctan (Arctangent) $$r_i = \alpha + \beta \arctan ( g(\bm{C}_i)) + \varepsilon_i$$
linear (Linear) $$r_i = g(\bm{C}_i) + \varepsilon_i$$
And \(g(\bm{C}) = c + \bm{C} w_g\), where \(\alpha\), \(\beta\), \(\kappa\), \(\rho\) are curve parameters,
\(c\) is a constant togglable by constant, \(\bm{C}\) are the regressors including the excess reserves. \(w_g\) their coefficients, and finally \(\varepsilon_i\) is the error term of the curve.
Chen, Z., Kourentzes, N., & Veyrune, R. (2023). Modeling the Reserve Demand to Facilitate Central Bank Operations. IMF Working Papers, 2023(179).
curve, and curveopt.