powered by
Fits a non-parametric reserve demand curve between excess reserves and normalised rates
npcurve(x, y, type = c("rforest", "spline"), dummy = NULL, q = NULL, ...)
Returns a model of class npcurvir. This includes
npcurvir
type the type of the curve.
type
fit the non-parametric model for the mean.
fit
fitQ The non-parametric model for the quantiles.
fitQ
data a list including the y, x, and dummy used for the fitting of the curve.
data
y
x
dummy
q the interval used in the fitting of the curve.
q
A matrix of explanatory variables. Excess reserve must be the first input.Additional regressor follow (optional).
A vector of normalised interest rates.
The type of the reserve demand curve. This can be any of rforecast for random forecast or spline for spline regression.
rforecast
spline
Optional input to signify a regime change (vertical shifts in the curve). Must be a vector of equal length to the rows of x. If not needed use NULL.
NULL
Target interval. This is a scalar below 1, for example 0.9 is the 90% interval. If NULL then no quantiles are estimated.
Additional arguments (unused).
Nikolaos Kourentzes, nikolaos@kourentzes.com
Chen, Z., Kourentzes, N., & Veyrune, R. (2023). Modeling the Reserve Demand to Facilitate Central Bank Operations. IMF Working Papers, 2023(179).
predict.npcurvir, and plot.npcurvir.
predict.npcurvir
plot.npcurvir
# Use ECB example data rate <- ecb$rate x <- ecb$x[,1,drop=FALSE] npcurve(x,rate)
Run the code above in your browser using DataLab